`tune-mv-integration` is written and maintained by many contributors.

tune-mv-integration: Authors
````````````````````````````

We'd like to thank the following people who have contributed to the `tune-mv-integration-python` repository.

- Avital Tzubeli <avital@tune.com>
- Ian Molee <ian@tune.com>
- Jeff Tanner <jefft@tune.com>
- Lee Brown <lee@tune.com>
- Ohad Lahav <ohad@tune.com>
- Stas Yasinov <stas@tune.com>
- Tuli Uchitel <tuli@tune.com>
- Zaq? Wiedmann <zaq@tune.com>